#

##

##

    	land

    	important

    			from goodest.shows_v2.treasure.nature.land._ops.develop import develop_land
    			land = develop_land ({
    				"collection": "essential_nutrients"
    			})

    	structure

    		{

    			#
    			#	These are the treasures that are added to the
    			#	grove.
    			#
    			"natures": [
    				{
    					#
    					#	This is the number of packages.
    					#
    					"amount": "1",

    					"identity": {
    						"name": "ASPARAGUS",
    						"FDC ID": "2390911",
    						"UPC": "07789048861",
    						"DSLD ID": ""
    					}
    				}
    			],

    			#
    			#	Theses are the sums of the various amounts
    			# 	contained within the treasure.
    			#
    			"measures": {
    				"mass + mass equivalents": {
    					"per recipe": {
    						"grams": {
    							"fraction string": "701493850988138503431/11258999068426240000",
    							"scinote string": "6.2305e+1"
    						}
    					}
    				},
    				"energy": {
    					"per recipe": {
    						"food calories": {
    							"fraction string": "918/5",
    							"scinote string": "1.8360e+2"
    						}
    					}
    				}
    			},

    			"grove": [
    				{
    					"info": {
    						"includes": [],
    						"names": [
    							"protein"
    						],
    						"region": 1
    					},
    					"measures": {
    						"mass + mass equivalents": {
    							"per recipe": {
    								"grams": {
    									"fraction string": "163994710149766829/3518437208883200",
    									"scinote string": "4.6610e+1"
    								}
    							},
    							"portion of grove": {
    								"fraction string": "2317946433212252000/3447786989728825129",
    								"scinote percentage string": "6.7230e+1"
    							}
    						}
    					},
    					"natures": [
    						{
    							"amount": "1",
    							"source": {
    								"name": "PLANT-BASED CHOPPED CHICK'N",
    								"FDC ID": "2510083",
    								"UPC": "850002856132",
    								"DSLD ID": ""
    							},
    							"ingredient": {
    								"name": "Protein"
    							},
    							"measures": {
    								"mass + mass equivalents": {
    									"per package": {
    										"listed": [
    											"46.610",
    											"g"
    										],
    										"grams": {
    											"scinote string": "4.6610e+1",
    											"decimal string": "46.610",
    											"fraction string": "163994710149766829/3518437208883200"
    										}
    									}
    								}
    							}
    						}
    					],
    					"unites": [],
    					"goals": {
    						"days of ingredient": {
    							"mass + mass equivalents": {
    								"per recipe": {
    									"fraction string": "163994710149766829/175921860444160000",
    									"decimal string": "0.932"
    								}
    							}
    						}
    					}
    				}
    			]
    		}